@@ -1,24 +1,23 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 from dataclasses import InitVar, dataclass
 from typing import Any, Mapping
 
 from airbyte_cdk.sources.streams.http.requests_native_auth.abstract_token import AbstractHeaderAuthenticator
-from dataclasses_jsonschema import JsonSchemaMixin
 
 
 @dataclass
-class DeclarativeAuthenticator(JsonSchemaMixin):
+class DeclarativeAuthenticator:
     """
     Interface used to associate which authenticators can be used as part of the declarative framework
     """
 
 
 @dataclass
-class NoAuth(AbstractHeaderAuthenticator, DeclarativeAuthenticator, JsonSchemaMixin):
-    options: InitVar[Mapping[str, Any]]
+class NoAuth(AbstractHeaderAuthenticator, DeclarativeAuthenticator):
+    parameters: InitVar[Mapping[str, Any]]
 
     @property
     def auth_header(self) -> str:
