@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 import logging
@@ -10,11 +10,10 @@ from typing import Any, List, Mapping, Tuple
 from airbyte_cdk.sources.declarative.checks.connection_checker import ConnectionChecker
 from airbyte_cdk.sources.source import Source
 from airbyte_cdk.sources.streams.http.availability_strategy import HttpAvailabilityStrategy
-from dataclasses_jsonschema import JsonSchemaMixin
 
 
 @dataclass
-class CheckStream(ConnectionChecker, JsonSchemaMixin):
+class CheckStream(ConnectionChecker):
     """
     Checks the connections by checking availability of one or many streams selected by the developer
 
@@ -23,10 +22,10 @@ class CheckStream(ConnectionChecker, JsonSchemaMixin):
     """
 
     stream_names: List[str]
-    options: InitVar[Mapping[str, Any]]
+    parameters: InitVar[Mapping[str, Any]]
 
-    def __post_init__(self, options: Mapping[str, Any]):
-        self._options = options
+    def __post_init__(self, parameters: Mapping[str, Any]):
+        self._parameters = parameters
 
     def check_connection(self, source: Source, logger: logging.Logger, config: Mapping[str, Any]) -> Tuple[bool, any]:
         streams = source.streams(config)
