@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 import datetime as dt
@@ -8,11 +8,10 @@ from typing import Any, Mapping, Union
 
 from airbyte_cdk.sources.declarative.datetime.datetime_parser import DatetimeParser
 from airbyte_cdk.sources.declarative.interpolation.interpolated_string import InterpolatedString
-from dataclasses_jsonschema import JsonSchemaMixin
 
 
 @dataclass
-class MinMaxDatetime(JsonSchemaMixin):
+class MinMaxDatetime:
     """
     Compares the provided date against optional minimum or maximum times. If date is earlier than
     min_date, then min_date is returned. If date is greater than max_date, then max_date is returned.
@@ -30,7 +29,7 @@ class MinMaxDatetime(JsonSchemaMixin):
     """
 
     datetime: Union[InterpolatedString, str]
-    options: InitVar[Mapping[str, Any]]
+    parameters: InitVar[Mapping[str, Any]]
     # datetime_format is a unique case where we inherit it from the parent if it is not specified before using the default value
     # which is why we need dedicated getter/setter methods and private dataclass field
     datetime_format: str = ""
@@ -38,20 +37,20 @@ class MinMaxDatetime(JsonSchemaMixin):
     min_datetime: Union[InterpolatedString, str] = ""
     max_datetime: Union[InterpolatedString, str] = ""
 
-    def __post_init__(self, options: Mapping[str, Any]):
-        self.datetime = InterpolatedString.create(self.datetime, options=options or {})
+    def __post_init__(self, parameters: Mapping[str, Any]):
+        self.datetime = InterpolatedString.create(self.datetime, parameters=parameters or {})
         self.timezone = dt.timezone.utc
         self._parser = DatetimeParser()
-        self.min_datetime = InterpolatedString.create(self.min_datetime, options=options) if self.min_datetime else None
-        self.max_datetime = InterpolatedString.create(self.max_datetime, options=options) if self.max_datetime else None
+        self.min_datetime = InterpolatedString.create(self.min_datetime, parameters=parameters) if self.min_datetime else None
+        self.max_datetime = InterpolatedString.create(self.max_datetime, parameters=parameters) if self.max_datetime else None
 
         self._timezone = dt.timezone.utc
 
-    def get_datetime(self, config, **additional_options) -> dt.datetime:
+    def get_datetime(self, config, **additional_parameters) -> dt.datetime:
         """
         Evaluates and returns the datetime
         :param config: The user-provided configuration as specified by the source's spec
-        :param additional_options: Additional arguments to be passed to the strings for interpolation
+        :param additional_parameters: Additional arguments to be passed to the strings for interpolation
         :return: The evaluated datetime
         """
         # We apply a default datetime format here instead of at instantiation, so it can be set by the parent first
@@ -59,14 +58,18 @@ class MinMaxDatetime(JsonSchemaMixin):
         if not datetime_format:
             datetime_format = "%Y-%m-%dT%H:%M:%S.%f%z"
 
-        time = self._parser.parse(str(self.datetime.eval(config, **additional_options)), datetime_format, self.timezone)
+        time = self._parser.parse(str(self.datetime.eval(config, **additional_parameters)), datetime_format, self.timezone)
 
         if self.min_datetime:
-            min_time = self._parser.parse(str(self.min_datetime.eval(config, **additional_options)), datetime_format, self.timezone)
-            time = max(time, min_time)
+            min_time = str(self.min_datetime.eval(config, **additional_parameters))
+            if min_time:
+                min_time = self._parser.parse(min_time, datetime_format, self.timezone)
+                time = max(time, min_time)
         if self.max_datetime:
-            max_time = self._parser.parse(str(self.max_datetime.eval(config, **additional_options)), datetime_format, self.timezone)
-            time = min(time, max_time)
+            max_time = str(self.max_datetime.eval(config, **additional_parameters))
+            if max_time:
+                max_time = self._parser.parse(max_time, datetime_format, self.timezone)
+                time = min(time, max_time)
         return time
 
     @property
