@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 import builtins
@@ -8,6 +8,7 @@ import numbers
 from typing import Union
 
 from dateutil import parser
+from isodate import parse_duration
 
 """
 This file contains macros that can be evaluated by a `JinjaInterpolation` object
@@ -83,7 +84,7 @@ def max(*args):
     return builtins.max(*args)
 
 
-def day_delta(num_days: int) -> str:
+def day_delta(num_days: int, format: str = "%Y-%m-%dT%H:%M:%S.%f%z") -> str:
     """
     Returns datetime of now() + num_days
 
@@ -93,7 +94,17 @@ def day_delta(num_days: int) -> str:
     :param num_days: number of days to add to current date time
     :return: datetime formatted as RFC3339
     """
-    return (datetime.datetime.now(datetime.timezone.utc) + datetime.timedelta(days=num_days)).strftime("%Y-%m-%dT%H:%M:%S.%f%z")
+    return (datetime.datetime.now(datetime.timezone.utc) + datetime.timedelta(days=num_days)).strftime(format)
+
+
+def duration(datestring: str):
+    """
+    Converts ISO8601 duration to datetime.timedelta
+
+    Usage:
+    `"{{ now_utc() - duration('P1D') }}"`
+    """
+    return parse_duration(datestring)
 
 
 def format_datetime(dt: Union[str, datetime.datetime], format: str):
@@ -108,5 +119,5 @@ def format_datetime(dt: Union[str, datetime.datetime], format: str):
     return parser.parse(dt).strftime(format)
 
 
-_macros_list = [now_local, now_utc, today_utc, timestamp, max, day_delta, format_datetime]
+_macros_list = [now_local, now_utc, today_utc, timestamp, max, day_delta, duration, format_datetime]
 macros = {f.__name__: f for f in _macros_list}
