@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 import re
@@ -7,16 +7,18 @@ from typing import Any, Mapping, Set, Tuple, Union
 
 from airbyte_cdk.sources.declarative.parsers.custom_exceptions import CircularReferenceException, UndefinedReferenceException
 
+REF_TAG = "$ref"
+
 
 class ManifestReferenceResolver:
     """
     An incoming manifest can contain references to values previously defined.
     This parser will dereference these values to produce a complete ConnectionDefinition.
 
-    References can be defined using a *ref(<arg>) string.
+    References can be defined using a #/<arg> string.
     ```
     key: 1234
-    reference: "*ref(key)"
+    reference: "#/key"
     ```
     will produce the following definition:
     ```
@@ -28,7 +30,7 @@ class ManifestReferenceResolver:
     key_value_pairs:
       k1: v1
       k2: v2
-    same_key_value_pairs: "*ref(key_value_pairs)"
+    same_key_value_pairs: "#/key_value_pairs"
     ```
     will produce the following definition:
     ```
@@ -46,7 +48,7 @@ class ManifestReferenceResolver:
       k1: v1
       k2: v2
     same_key_value_pairs:
-      $ref: "*ref(key_value_pairs)"
+      $ref: "#/key_value_pairs"
       k3: v3
     ```
     will produce the following definition:
@@ -66,7 +68,7 @@ class ManifestReferenceResolver:
     ```
     dict:
         limit: 50
-    limit_ref: "*ref(dict.limit)"
+    limit_ref: "#/dict/limit"
     ```
     will produce the following definition:
     ```
@@ -75,18 +77,18 @@ class ManifestReferenceResolver:
     limit-ref: 50
     ```
 
-    whereas here we want to access the `nested.path` value.
+    whereas here we want to access the `nested/path` value.
     ```
     nested:
         path: "first one"
-    nested.path: "uh oh"
-    value: "ref(nested.path)
+    nested/path: "uh oh"
+    value: "#/nested/path
     ```
     will produce the following definition:
     ```
     nested:
         path: "first one"
-    nested.path: "uh oh"
+    nested/path: "uh oh"
     value: "uh oh"
     ```
 
@@ -94,8 +96,6 @@ class ManifestReferenceResolver:
     until we find a key with the given path, or until there is nothing to traverse.
     """
 
-    ref_tag = "$ref"
-
     def preprocess_manifest(self, manifest: Mapping[str, Any]) -> Mapping[str, Any]:
         """
         :param manifest: incoming manifest that could have references to previously defined components
@@ -103,12 +103,12 @@ class ManifestReferenceResolver:
         """
         return self._evaluate_node(manifest, manifest, set())
 
-    def _evaluate_node(self, node: Any, manifest: Mapping[str, Any], visited: Set):
+    def _evaluate_node(self, node: Any, manifest: Mapping[str, Any], visited: Set) -> Any:
         if isinstance(node, dict):
             evaluated_dict = {k: self._evaluate_node(v, manifest, visited) for k, v in node.items() if not self._is_ref_key(k)}
-            if self.ref_tag in node:
+            if REF_TAG in node:
                 # The node includes a $ref key, so we splat the referenced value(s) into the evaluated dict
-                evaluated_ref = self._evaluate_node(node[self.ref_tag], manifest, visited)
+                evaluated_ref = self._evaluate_node(node[REF_TAG], manifest, visited)
                 if not isinstance(evaluated_ref, dict):
                     return evaluated_ref
                 else:
@@ -118,50 +118,55 @@ class ManifestReferenceResolver:
                 return evaluated_dict
         elif isinstance(node, list):
             return [self._evaluate_node(v, manifest, visited) for v in node]
-        elif isinstance(node, str) and node.startswith("*ref("):
+        elif self._is_ref(node):
             if node in visited:
                 raise CircularReferenceException(node)
             visited.add(node)
-            ret = self._evaluate_node(self._lookup_reference_value(node, manifest), manifest, visited)
+            ret = self._evaluate_node(self._lookup_ref_value(node, manifest), manifest, visited)
             visited.remove(node)
             return ret
         else:
             return node
 
-    def _is_ref_key(self, key):
-        return key == self.ref_tag
-
-    def _lookup_reference_value(self, reference: str, manifest: Mapping[str, Any]) -> Any:
-        path = re.match("\\*ref\\(([^)]+)\\)", reference).groups()[0]
+    def _lookup_ref_value(self, ref: str, manifest: Mapping[str, Any]) -> Any:
+        path = re.match(r"#/(.*)", ref).groups()[0]
         if not path:
-            raise UndefinedReferenceException(path, reference)
+            raise UndefinedReferenceException(path, ref)
         try:
-            return self._read_reference_value(path, manifest)
-        except (KeyError, IndexError):
-            raise UndefinedReferenceException(path, reference)
+            return self._read_ref_value(path, manifest)
+        except (AttributeError, KeyError, IndexError):
+            raise UndefinedReferenceException(path, ref)
 
     @staticmethod
-    def _read_reference_value(ref: str, manifest_node: Mapping[str, Any]) -> Any:
+    def _is_ref(node: Any) -> bool:
+        return isinstance(node, str) and node.startswith("#/")
+
+    @staticmethod
+    def _is_ref_key(key) -> bool:
+        return key == REF_TAG
+
+    @staticmethod
+    def _read_ref_value(ref: str, manifest_node: Mapping[str, Any]) -> Any:
         """
         Read the value at the referenced location of the manifest.
 
-        References are ambiguous because one could define a key containing `.`
+        References are ambiguous because one could define a key containing `/`
         In this example, we want to refer to the `limit` key in the `dict` object:
             dict:
                 limit: 50
-            limit_ref: "*ref(dict.limit)"
+            limit_ref: "#/dict/limit"
 
-        Whereas here we want to access the `nested.path` value.
+        Whereas here we want to access the `nested/path` value.
           nested:
             path: "first one"
-          nested.path: "uh oh"
-          value: "ref(nested.path)
+          nested/path: "uh oh"
+          value: "#/nested/path"
 
         To resolve the ambiguity, we try looking for the reference key at the top level, and then traverse the structs downward
         until we find a key with the given path, or until there is nothing to traverse.
 
-        Consider the path foo.bar.baz. To resolve the ambiguity, we first try 'foo.bar.baz' in its entirety as a top-level key. If this
-        fails, we try 'foo' as the top-level key, and if this succeeds, pass 'bar.baz' on as the key to be tried at the next level.
+        Consider the path foo/bar/baz. To resolve the ambiguity, we first try 'foo/bar/baz' in its entirety as a top-level key. If this
+        fails, we try 'foo' as the top-level key, and if this succeeds, pass 'bar/baz' on as the key to be tried at the next level.
         """
         while ref:
             try:
@@ -178,18 +183,20 @@ def _parse_path(ref: str) -> Tuple[Union[str, int], str]:
 
     A path component may be a string key, or an int index.
 
-    >>> _parse_path("foo.bar")
+    >>> _parse_path("foo/bar")
     "foo", "bar"
-    >>> _parse_path("foo[7][8].bar")
-    "foo", "[7][8].bar"
-    >>> _parse_path("[7][8].bar")
-    7, "[8].bar"
-    >>> _parse_path("[8].bar")
+    >>> _parse_path("foo/7/8/bar")
+    "foo", "7/8/bar"
+    >>> _parse_path("7/8/bar")
+    7, "8/bar"
+    >>> _parse_path("8/bar")
     8, "bar"
+    >>> _parse_path("8foo/bar")
+    "8foo", "bar"
     """
-    if match := re.match(r"^\[([0-9]+)\]\.?(.*)", ref):
-        idx, rest = match.groups()
-        result = int(idx), rest
-    else:
-        result = re.match(r"([^[.]*)\.?(.*)", ref).groups()
-    return result
+    match = re.match(r"([^/]*)/?(.*)", ref)
+    first, rest = match.groups()
+    try:
+        return int(first), rest
+    except ValueError:
+        return first, rest
