@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 from dataclasses import InitVar, dataclass
@@ -7,11 +7,10 @@ from typing import Any, List, Mapping, Optional
 
 import requests
 from airbyte_cdk.sources.declarative.requesters.paginators.strategies.pagination_strategy import PaginationStrategy
-from dataclasses_jsonschema import JsonSchemaMixin
 
 
 @dataclass
-class PageIncrement(PaginationStrategy, JsonSchemaMixin):
+class PageIncrement(PaginationStrategy):
     """
     Pagination strategy that returns the number of pages reads so far and returns it as the next page token
 
@@ -21,10 +20,10 @@ class PageIncrement(PaginationStrategy, JsonSchemaMixin):
     """
 
     page_size: int
-    options: InitVar[Mapping[str, Any]]
+    parameters: InitVar[Mapping[str, Any]]
     start_from_page: int = 0
 
-    def __post_init__(self, options: Mapping[str, Any]):
+    def __post_init__(self, parameters: Mapping[str, Any]):
         self._page = self.start_from_page
 
     def next_page_token(self, response: requests.Response, last_records: List[Mapping[str, Any]]) -> Optional[Any]:
