@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 from abc import abstractmethod
@@ -7,11 +7,10 @@ from dataclasses import dataclass
 from typing import Any, List, Mapping, Optional
 
 import requests
-from dataclasses_jsonschema import JsonSchemaMixin
 
 
 @dataclass
-class PaginationStrategy(JsonSchemaMixin):
+class PaginationStrategy:
     """
     Defines how to get the next page token
     """
