@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 from abc import abstractmethod
@@ -7,11 +7,10 @@ from dataclasses import dataclass
 from typing import Optional
 
 from airbyte_cdk.sources.declarative.types import Config, Record, StreamSlice, StreamState
-from dataclasses_jsonschema import JsonSchemaMixin
 
 
 @dataclass
-class RecordTransformation(JsonSchemaMixin):
+class RecordTransformation:
     """
     Implementations of this class define transformations that can be applied to records of a stream.
     """
