@@ -1,16 +1,21 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 
+import logging
 from typing import Any, List, Mapping, MutableMapping, Optional, Tuple
 
+import backoff
 import pendulum
 import requests
 from deprecated import deprecated
 
+from ..exceptions import DefaultBackoffException
 from .core import HttpAuthenticator
 
+logger = logging.getLogger("airbyte")
+
 
 @deprecated(version="0.1.20", reason="Use airbyte_cdk.sources.streams.http.requests_native_auth.Oauth2Authenticator instead")
 class Oauth2Authenticator(HttpAuthenticator):
@@ -69,6 +74,14 @@ class Oauth2Authenticator(HttpAuthenticator):
 
         return payload
 
+    @backoff.on_exception(
+        backoff.expo,
+        DefaultBackoffException,
+        on_backoff=lambda details: logger.info(
+            f"Caught retryable error after {details['tries']} tries. Waiting {details['wait']} seconds then retrying..."
+        ),
+        max_time=300,
+    )
     def refresh_access_token(self) -> Tuple[str, int]:
         """
         returns a tuple of (access_token, token_lifespan_in_seconds)
@@ -83,6 +96,10 @@ class Oauth2Authenticator(HttpAuthenticator):
             response.raise_for_status()
             response_json = response.json()
             return response_json["access_token"], response_json["expires_in"]
+        except requests.exceptions.RequestException as e:
+            if e.response.status_code == 429 or e.response.status_code >= 500:
+                raise DefaultBackoffException(request=e.response.request, response=e.response)
+            raise
         except Exception as e:
             raise Exception(f"Error while refreshing access token: {e}") from e
 
