@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 import json
@@ -10,13 +10,13 @@ from airbyte_cdk.sources.declarative.decoders.json_decoder import JsonDecoder
 from airbyte_cdk.sources.declarative.extractors.dpath_extractor import DpathExtractor
 
 config = {"field": "record_array"}
-options = {"options_field": "record_array"}
+parameters = {"parameters_field": "record_array"}
 
-decoder = JsonDecoder(options={})
+decoder = JsonDecoder(parameters={})
 
 
 @pytest.mark.parametrize(
-    "test_name, field_pointer, body, expected_records",
+    "test_name, field_path, body, expected_records",
     [
         ("test_extract_from_array", ["data"], {"data": [{"id": 1}, {"id": 2}]}, [{"id": 1}, {"id": 2}]),
         ("test_extract_single_record", ["data"], {"data": {"id": 1}}, [{"id": 1}]),
@@ -24,14 +24,19 @@ decoder = JsonDecoder(options={})
         ("test_extract_from_root_array", [], [{"id": 1}, {"id": 2}], [{"id": 1}, {"id": 2}]),
         ("test_nested_field", ["data", "records"], {"data": {"records": [{"id": 1}, {"id": 2}]}}, [{"id": 1}, {"id": 2}]),
         ("test_field_in_config", ["{{ config['field'] }}"], {"record_array": [{"id": 1}, {"id": 2}]}, [{"id": 1}, {"id": 2}]),
-        ("test_field_in_options", ["{{ options['options_field'] }}"], {"record_array": [{"id": 1}, {"id": 2}]}, [{"id": 1}, {"id": 2}]),
+        (
+            "test_field_in_parameters",
+            ["{{ parameters['parameters_field'] }}"],
+            {"record_array": [{"id": 1}, {"id": 2}]},
+            [{"id": 1}, {"id": 2}],
+        ),
         ("test_field_does_not_exist", ["record"], {"id": 1}, []),
         ("test_nested_list", ["list", "*", "item"], {"list": [{"item": {"id": "1"}}]}, [{"id": "1"}]),
         ("test_complex_nested_list", ['data', '*', 'list', 'data2', '*'], {"data": [{"list": {"data2": [{"id": 1}, {"id": 2}]}},{"list": {"data2": [{"id": 3}, {"id": 4}]}}]}, [{"id": 1}, {"id": 2}, {"id": 3}, {"id": 4}])
     ],
 )
-def test_dpath_extractor(test_name, field_pointer, body, expected_records):
-    extractor = DpathExtractor(field_pointer=field_pointer, config=config, decoder=decoder, options=options)
+def test_dpath_extractor(test_name, field_path, body, expected_records):
+    extractor = DpathExtractor(field_path=field_path, config=config, decoder=decoder, parameters=parameters)
 
     response = create_response(body)
     actual_records = extractor.extract_records(response)
