@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 import pytest
@@ -13,7 +13,7 @@ from airbyte_cdk.sources.declarative.interpolation.interpolated_mapping import I
         ("test_number", "number", 100),
         ("test_field_to_interpolate_from_config", "field_to_interpolate_from_config", "VALUE_FROM_CONFIG"),
         ("test_field_to_interpolate_from_kwargs", "field_to_interpolate_from_kwargs", "VALUE_FROM_KWARGS"),
-        ("test_field_to_interpolate_from_options", "field_to_interpolate_from_options", "VALUE_FROM_OPTIONS"),
+        ("test_field_to_interpolate_from_parameters", "field_to_interpolate_from_parameters", "VALUE_FROM_PARAMETERS"),
         ("test_key_is_interpolated", "key", "VALUE"),
     ],
 )
@@ -23,12 +23,12 @@ def test(test_name, key, expected_value):
         "number": 100,
         "field_to_interpolate_from_config": "{{ config['c'] }}",
         "field_to_interpolate_from_kwargs": "{{ kwargs['a'] }}",
-        "field_to_interpolate_from_options": "{{ options['b'] }}",
-        "{{ options.k }}": "VALUE",
+        "field_to_interpolate_from_parameters": "{{ parameters['b'] }}",
+        "{{ parameters.k }}": "VALUE",
     }
     config = {"c": "VALUE_FROM_CONFIG"}
     kwargs = {"a": "VALUE_FROM_KWARGS"}
-    mapping = InterpolatedMapping(mapping=d, options={"b": "VALUE_FROM_OPTIONS", "k": "key"})
+    mapping = InterpolatedMapping(mapping=d, parameters={"b": "VALUE_FROM_PARAMETERS", "k": "key"})
 
     interpolated = mapping.eval(config, **{"kwargs": kwargs})
 
