@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 import json
@@ -163,6 +163,24 @@ class TestOauth2Authenticator:
 
         assert ("access_token", 1000) == token
 
+    @pytest.mark.parametrize("error_code", (429, 500, 502, 504))
+    def test_refresh_access_token_retry(self, error_code, requests_mock):
+        oauth = Oauth2Authenticator(
+            f"https://{TestOauth2Authenticator.refresh_endpoint}",
+            TestOauth2Authenticator.client_id,
+            TestOauth2Authenticator.client_secret,
+            TestOauth2Authenticator.refresh_token
+        )
+        requests_mock.post(
+            f"https://{TestOauth2Authenticator.refresh_endpoint}",
+            [
+                {"status_code": error_code}, {"status_code": error_code}, {"json": {"access_token": "token", "expires_in": 10}}
+            ]
+        )
+        token, expires_in = oauth.refresh_access_token()
+        assert (token, expires_in) == ("token", 10)
+        assert requests_mock.call_count == 3
+
     def test_auth_call_method(self, mocker):
         oauth = Oauth2Authenticator(
             token_refresh_endpoint=TestOauth2Authenticator.refresh_endpoint,
